@@ -2,6 +2,11 @@
 # under the 3-Clause BSD License. Please see 'LICENSE.rst' for further
 # information.
 
+"""
+This subpackage is used for reading and writing trajectories in the
+compressed *Gromacs* XTC format.
+"""
+
 __author__ = "Patrick Kunzmann"
 
 from .file import *
\ No newline at end of file
