@@ -121,10 +121,9 @@ def apply_residue_wise(array, data, function, axis=None):
     >>> print(len(sasa_per_residue))
     20
     >>> print(sasa_per_residue)
-    [157.97867    117.136475    94.98269    115.485115   113.58283
-      23.470863    93.0127     144.17316     61.561058    38.885334
-       0.79210365 114.05285    108.56837     27.887915    83.58345
-     113.01639    114.31787     74.28113     47.810623   172.03488   ]
+    [157.979 117.136  94.983 115.485 113.583  23.471  93.013 144.173  61.561
+      38.885   0.792 114.053 108.568  27.888  83.583 113.016 114.318  74.281
+      47.811 172.035]
 
     Calculate the centroids of each residue for the same peptide.
         
@@ -135,26 +134,26 @@ def apply_residue_wise(array, data, function, axis=None):
     >>> print(len(centroids))
     20
     >>> print(centroids)
-    [[-9.581938    3.3778126  -2.0728126 ]
-     [-4.6695266   5.815737   -1.8598946 ]
-     [-2.4608097   3.0596666   3.0760477 ]
-     [-7.2108426  -0.39636838  1.0131578 ]
-     [-4.6978235  -1.0804706  -4.284117  ]
-     [ 1.1721249   0.20641668  1.038375  ]
-     [-2.1600525  -2.2449472   3.5405266 ]
-     [-3.6823182  -5.5397725  -2.8952727 ]
-     [ 0.71108335 -5.4094167  -2.5495    ]
-     [ 2.0024288  -6.321715    1.6952857 ]
-     [ 2.7985713  -3.1399999   2.3274286 ]
-     [ 5.9007144  -2.4889286   4.844571  ]
-     [ 6.7537274  -6.7123637   3.0941818 ]
-     [ 5.6992726  -5.100636   -1.2091817 ]
-     [ 9.295427   -2.9695716  -1.8352858 ]
-     [ 5.517959   -1.5212501  -3.472667  ]
-     [ 7.218929    3.6732144  -0.6843571 ]
-     [ 4.006643    4.3640003   2.673857  ]
-     [ 0.34114286  5.575286   -0.25428572]
-     [ 1.194      10.416249    1.1301666 ]]
+    [[-9.582  3.378 -2.073]
+     [-4.670  5.816 -1.860]
+     [-2.461  3.060  3.076]
+     [-7.211 -0.396  1.013]
+     [-4.698 -1.080 -4.284]
+     [ 1.172  0.206  1.038]
+     [-2.160 -2.245  3.541]
+     [-3.682 -5.540 -2.895]
+     [ 0.711 -5.409 -2.549]
+     [ 2.002 -6.322  1.695]
+     [ 2.799 -3.140  2.327]
+     [ 5.901 -2.489  4.845]
+     [ 6.754 -6.712  3.094]
+     [ 5.699 -5.101 -1.209]
+     [ 9.295 -2.970 -1.835]
+     [ 5.518 -1.521 -3.473]
+     [ 7.219  3.673 -0.684]
+     [ 4.007  4.364  2.674]
+     [ 0.341  5.575 -0.254]
+     [ 1.194 10.416  1.130]]
     """
     # The exclusive stop is appended to the residue starts
     starts = np.append(get_residue_starts(array), [array.array_length()])
