@@ -15,4 +15,4 @@ def test_rotate_centered():
     file.read(join(data_dir, "1l2y.npz"))
     array = file.get_structure()[0]
     rotated = struc.rotate_centered(array, [2*np.pi, 2*np.pi, 2*np.pi])
-    assert np.sum(rotated.coord-array.coord) == pytest.approx(0)
\ No newline at end of file
+    assert np.sum(rotated.coord-array.coord) == pytest.approx(0, abs=1e-4)
\ No newline at end of file
